pub struct Reader { /* private fields */ }Expand description
Generic archive reader that returns manifest headers, entry headers, and compressed output.
The caller should check if the archive is encrypted by calling the
is_encrypted() function, and if it returns true, then call
enable_encryption() with a password provided by the user.
Implementations